@@ -157,8 +157,9 @@ impl Client {
         let res = self
             .send_query(Query::Data(DataQuery::Blob(BlobRead::Get(address))))
             .await?;
-        let data: Blob = match res {
-            QueryResponse::GetBlob(res) => res.map_err(Error::from),
+        let msg_id = res.msg_id;
+        let data: Blob = match res.response {
+            QueryResponse::GetBlob(result) => result.map_err(|err| Error::from((err, msg_id))),
             _ => return Err(Error::ReceivedUnexpectedEvent),
         }?;
 
@@ -416,7 +417,10 @@ mod tests {
             .await;
         match res {
             Ok(data) => bail!("Pub blob should not exist yet: {:?}", data),
-            Err(Error::ErrorMessage(ErrorMessage::NoSuchData)) => (),
+            Err(Error::ErrorMessage {
+                source: ErrorMessage::DataNotFound(_),
+                ..
+            }) => (),
             Err(e) => bail!("Unexpected: {:?}", e),
         }
         // Put blob
@@ -452,7 +456,10 @@ mod tests {
 
         match res {
             Ok(_) => bail!("Private blob should not exist yet"),
-            Err(Error::ErrorMessage(ErrorMessage::NoSuchData)) => (),
+            Err(Error::ErrorMessage {
+                source: ErrorMessage::DataNotFound(_),
+                ..
+            }) => (),
             Err(e) => bail!("Unexpected: {:?}", e),
         }
 
@@ -477,7 +484,10 @@ mod tests {
         )
         .await
         {
-            Ok(Some(Error::ErrorMessage(ErrorMessage::DataExists))) => {
+            Ok(Some(Error::ErrorMessage {
+                source: ErrorMessage::DataExists,
+                ..
+            })) => {
                 // Ok
             }
             Ok(Some(error)) => bail!("Expecting DataExists error got: {:?}", error),
@@ -717,7 +727,10 @@ mod tests {
         // attempt to retrieve it with generated address (it should error)
         let res = client.read_blob(*address_before, None, None).await;
         match res {
-            Err(Error::ErrorMessage(ErrorMessage::NoSuchData)) => (),
+            Err(Error::ErrorMessage {
+                source: ErrorMessage::DataNotFound(_),
+                ..
+            }) => (),
             Ok(_) => bail!("Blob unexpectedly retrieved using address generated by gen_data_map"),
             Err(_) => bail!(
                 "Unexpected error when Blob retrieved using address generated by gen_data_map"
